/* gcc -g -Wall -o shoot shoot.c `pkg-config --cflags --libs ecore-evas` */

#include <stdlib.h>

#include <Evas.h>
#include <Ecore.h>
#include <Ecore_Evas.h>

#define MAX_STARS 10

static double star_fps[] = { 0.05, 0.03, 0.02 };

typedef struct
{
  int x;
  int y;
  Evas_Object *o;
  Ecore_Timer *timer;
} star_t;

static star_t stars[MAX_STARS];

Eina_Bool star_cb(void *data)
{
  star_t *s = (star_t *)data;

  evas_object_move(s->o, s->x, s->y++);

  return EINA_TRUE;
}

void
stars_init(Evas *evas)
{
  char buf[10];
  Evas_Object *o;
  Evas_Coord w;
  Evas_Coord h;
  int i;

  srand(time(NULL));

  for (i = 0; i < MAX_STARS; i++)
    {
      int r;
      int type;

      r = rand();
      if (r < (RAND_MAX / 3))
        type = 0;
      else if (r < (2 * (RAND_MAX / 3)))
        type = 1;
      else
        type = 2;

      r = rand();
      stars[i].x = (int)((r * 640.0) / RAND_MAX);
      r = rand();
      stars[i].y = (int)((r * 480.0) / RAND_MAX);

      sprintf(buf, "star%d.png", type);
      o = evas_object_image_add(evas);
      evas_object_image_file_set(o, buf, NULL);
      evas_object_image_size_get (o, &w, &h);
      evas_object_image_fill_set(o, 0, 0, w, h);
      evas_object_image_size_set(o, w, h);
      evas_object_resize(o, w, h);
      evas_object_move (o, stars[i].x, stars[i].y);
      evas_object_show (o);
      stars[i].o = o;

      stars[i].timer = ecore_timer_add(star_fps[type], star_cb, stars + i);
    }
}


Evas_Object *r1;
Evas_Object *r2;
Evas_Object *r3;

Eina_Bool bg(void *data)
{
  Evas_Coord x;
  Evas_Coord y;

  evas_object_geometry_get(r1, &x, &y, NULL, NULL);
  y++;
  evas_object_move(r1, x, y);
  if (y > 480) evas_object_del(r1);

  evas_object_geometry_get(r2, &x, &y, NULL, NULL);
  y++;
  evas_object_move(r2, x, y);
  if (y > 480) evas_object_del(r2);

  evas_object_geometry_get(r3, &x, &y, NULL, NULL);
  y++;
  evas_object_move(r3, x, y);
  if (y > 480) evas_object_del(r3);



  return EINA_TRUE;
}

int main()
{
  Ecore_Evas *ee;
  Evas *evas;
  Evas_Object *o;
  Ecore_Timer *timer;

  if (!ecore_evas_init())
    return EXIT_FAILURE;

  ee = ecore_evas_new(NULL, 10, 10, 640, 480, NULL);
  if (!ee)
    goto shutdown_ecore_evas;

  evas = ecore_evas_get(ee);

  o = evas_object_rectangle_add(evas);
  evas_object_resize(o, 640, 480);
  evas_object_color_set(o, 0, 0, 0, 0);
  evas_object_move(o, 0, 0);
  evas_object_show(o);

  o = evas_object_rectangle_add(evas);
  evas_object_resize(o, 20, 40);
  evas_object_color_set(o, 255, 0, 0, 255);
  evas_object_move(o, 0, 10);
  evas_object_show(o);
  r1 = o;

  o = evas_object_rectangle_add(evas);
  evas_object_resize(o, 30, 60);
  evas_object_color_set(o, 0, 255, 0, 255);
  evas_object_move(o, 0, 50);
  evas_object_show(o);
  r2 = o;

  o = evas_object_rectangle_add(evas);
  evas_object_resize(o, 15, 80);
  evas_object_color_set(o, 0, 0, 255, 255);
  evas_object_move(o, 0, 110);
  evas_object_show(o);
  r3 = o;

  timer = ecore_timer_add(0.01, bg, NULL);

  stars_init(evas);

  ecore_evas_show(ee);

  ecore_main_loop_begin();

  ecore_evas_shutdown();

  return EXIT_SUCCESS;

 shutdown_ecore_evas:
  ecore_evas_shutdown();

  return EXIT_FAILURE;
}
